(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core')) :
    typeof define === 'function' && define.amd ? define('ngx-overflow-shadow', ['exports', '@angular/core'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-overflow-shadow'] = {}, global.ng.core));
}(this, (function (exports, core) { 'use strict';

    var NgxOverflowShadowDirective = /** @class */ (function () {
        function NgxOverflowShadowDirective(renderer, elementRef) {
            this.renderer = renderer;
            this.elementRef = elementRef;
            this.top = false;
            this.bottom = true;
            this.shadowStyle = '0 0 8px 1px rgba(0, 0, 0, 0.5)';
        }
        NgxOverflowShadowDirective.prototype.ngAfterViewInit = function () {
            this.init();
        };
        NgxOverflowShadowDirective.prototype.ngOnDestroy = function () {
            if (this.top) {
                this.topIntersectionObserver.disconnect();
            }
            if (this.bottom) {
                this.bottomIntersectionObserver.disconnect();
            }
        };
        NgxOverflowShadowDirective.prototype.init = function () {
            if (this.top) {
                this.initTopShadow();
            }
            if (this.bottom) {
                this.initBottomShadow();
            }
        };
        NgxOverflowShadowDirective.prototype.initTopShadow = function () {
            var nativeElement = this.elementRef.nativeElement;
            this.createTopShadowDiv(nativeElement);
            this.createTopIntersectionObserver(nativeElement);
            this.createTopPlaceholderDiv(nativeElement);
        };
        NgxOverflowShadowDirective.prototype.initBottomShadow = function () {
            var nativeElement = this.elementRef.nativeElement;
            this.createBottomShadowDiv(nativeElement);
            this.createBottomIntersectionObserver(nativeElement);
            this.createBottomPlaceholderDiv(nativeElement);
        };
        NgxOverflowShadowDirective.prototype.createTopShadowDiv = function (nativeElement) {
            this.topShadowDiv = this.renderer.createElement('div');
            this.renderer.setStyle(this.topShadowDiv, 'position', 'sticky');
            this.renderer.setStyle(this.topShadowDiv, 'top', 0);
            this.renderer.insertBefore(nativeElement, this.topShadowDiv, nativeElement.firstChild);
        };
        NgxOverflowShadowDirective.prototype.createBottomShadowDiv = function (nativeElement) {
            this.bottomShadowDiv = this.renderer.createElement('div');
            this.renderer.setStyle(this.bottomShadowDiv, 'position', 'sticky');
            this.renderer.setStyle(this.bottomShadowDiv, 'bottom', 0);
            this.renderer.appendChild(nativeElement, this.bottomShadowDiv);
        };
        NgxOverflowShadowDirective.prototype.createTopIntersectionObserver = function (nativeElement) {
            this.topIntersectionObserver = new IntersectionObserver(this.callback.bind(this, this.topShadowDiv), { root: nativeElement });
        };
        NgxOverflowShadowDirective.prototype.createBottomIntersectionObserver = function (nativeElement) {
            this.bottomIntersectionObserver = new IntersectionObserver(this.callback.bind(this, this.bottomShadowDiv), { root: nativeElement });
        };
        NgxOverflowShadowDirective.prototype.createTopPlaceholderDiv = function (nativeElement) {
            var topPlaceholderDiv = this.renderer.createElement('div');
            this.renderer.insertBefore(nativeElement, topPlaceholderDiv, nativeElement.firstChild);
            this.topIntersectionObserver.observe(topPlaceholderDiv);
        };
        NgxOverflowShadowDirective.prototype.createBottomPlaceholderDiv = function (nativeElement) {
            var bottomPlaceholderDiv = this.renderer.createElement('div');
            this.renderer.appendChild(nativeElement, bottomPlaceholderDiv);
            this.bottomIntersectionObserver.observe(bottomPlaceholderDiv);
        };
        NgxOverflowShadowDirective.prototype.callback = function (shadowDiv, entries) {
            var isIntersecting = entries.find(function (entry) { return entry.isIntersecting; });
            if (isIntersecting) {
                this.renderer.removeStyle(shadowDiv, 'boxShadow');
            }
            else {
                this.renderer.setStyle(shadowDiv, 'boxShadow', this.shadowStyle);
            }
        };
        return NgxOverflowShadowDirective;
    }());
    NgxOverflowShadowDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[ngxOverflowShadow]'
                },] }
    ];
    NgxOverflowShadowDirective.ctorParameters = function () { return [
        { type: core.Renderer2 },
        { type: core.ElementRef }
    ]; };
    NgxOverflowShadowDirective.propDecorators = {
        top: [{ type: core.Input }],
        bottom: [{ type: core.Input }],
        shadowStyle: [{ type: core.Input }]
    };

    var NgxOverflowShadowModule = /** @class */ (function () {
        function NgxOverflowShadowModule() {
        }
        return NgxOverflowShadowModule;
    }());
    NgxOverflowShadowModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [NgxOverflowShadowDirective],
                    exports: [NgxOverflowShadowDirective]
                },] }
    ];

    /*
     * Public API Surface of ngx-overflow-shadow
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NgxOverflowShadowDirective = NgxOverflowShadowDirective;
    exports.NgxOverflowShadowModule = NgxOverflowShadowModule;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-overflow-shadow.umd.js.map
